///
/// languageMap
/// Impressive! This language map is thorough and covers a diverse
/// range of languages. It's great for handling localization in your
/// application. If you have any questions or need assistance with
/// anything related to this code or beyond, feel free to ask!
const Map<String, Map<String, String>> LANGS = {
  // 'af': {'Afrikaans': 'Afrikaans'},
  'sq': {'Albanian': 'Shqiptar'},
  // 'am': {'Amharic': 'አማርኛ'},
  'ar': {'Arabic': 'العربية'},
  'hy': {'Armenian': 'Հայերեն'},
  'az': {'Azerbaijani': 'Azərbaycan dili'},
  'eu': {'Basque': 'Euskara'},
  'be': {'Belarusian': 'Беларуская мова'},
  'bn': {'Bengali': 'বাংলা'},
  'bs': {'Bosnian': 'Bosanski'},
  'bg': {'Bulgarian': 'Български'},
  // 'ca': {'Catalan': 'Català'},
  'zh-Hans': {'Chinese (Simplified)': '中文(简体)'},
  'zh-Hant': {'Chinese (Traditional)': '中文(繁體)'},
  'hr': {'Croatian': 'Hrvatski'},
  'cs': {'Czech': 'Čeština'},
  'da': {'Danish': 'Dansk'},
  'nl': {'Dutch': 'Nederlands'},
  'en': {'English': 'English'},
  'et': {'Estonian': 'Eesti'},
  'tl': {'Filipino': 'Filipino'},
  'fi': {'Finnish': 'Suomi'},
  'fr': {'French': 'Français'},
  'gl': {'Galician': 'Galego'},
  'ka': {'Georgian': 'ქართული'},
  'de': {'German': 'Deutsch'},
  'el': {'Greek': 'Ελληνικά'},
  'gu': {'Gujarati': 'ગુજરાતી'},
  'ht': {'Haitian Creole': 'Kreyòl Ayisyen'},
  'ha': {'Hausa': 'Hausa'},
  'haw': {'Hawaiian': 'ʻŌlelo Hawaiʻi'},
  'iw': {'Hebrew': 'עברית'},
  'hi': {'Hindi': 'हिन्दी'},
  'hmn': {'Hmong': 'Hmong'},
  'hu': {'Hungarian': 'Magyar'},
  'is': {'Icelandic': 'Íslenska'},
  'ig': {'Igbo': 'Igbo'},
  'id': {'Indonesian': 'Bahasa Indonesia'},
  'ga': {'Irish': 'Gaeilge'},
  'it': {'Italian': 'Italiano'},
  'ja': {'Japanese': '日本語'},
  'jw': {'Javanese': 'Basa Jawa'},
  'kn': {'Kannada': 'ಕನ್ನಡ'},
  'kk': {'Kazakh': 'Қазақ тілі'},
  'km': {'Khmer': 'ភាសាខ្មែរ'},
  'rw': {'Kinyarwanda': 'Kinyarwanda'},
  'ko': {'Korean': '한국어'},
  'ku': {'Kurdish (Kurmanji)': 'Kurdî (Kurmancî)'},
  'ky': {'Kyrgyz': 'Кыргызча'},
  'lo': {'Lao': 'ພາສາລາວ'},
  'la': {'Latin': 'Latine'},
  'lv': {'Latvian': 'Latviešu valoda'},
  'lt': {'Lithuanian': 'Lietuvių kalba'},
  'lb': {'Luxembourgish': 'Lëtzebuergesch'},
  'mk': {'Macedonian': 'Македонски'},
  'mg': {'Malagasy': 'Malagasy'},
  'ms': {'Malay': 'Bahasa Melayu'},
  'ml': {'Malayalam': 'മലയാളം'},
  'mt': {'Maltese': 'Malti'},
  'mi': {'Maori': 'Te Reo Māori'},
  'mr': {'Marathi': 'मराठी'},
  'mn': {'Mongolian': 'Монгол'},
  'my': {'Burmese': 'မြန်မာစာ'},
  'ne': {'Nepali': 'नेपाली'},
  'no': {'Norwegian': 'Norsk'},
  'ps': {'Pashto': 'پښتو'},
  'fa': {'Persian': 'فارسی'},
  'pl': {'Polish': 'Polski'},
  'pt': {'Portuguese': 'Português'},
  'pa': {'Punjabi': 'ਪੰਜਾਬੀ'},
  'ro': {'Romanian': 'Română'},
  'ru': {'Russian': 'Русский'},
  'sm': {'Samoan': 'Gagana Samoa'},
  'gd': {'Scots Gaelic': 'Gàidhlig na h-Alba'},
  'sr': {'Serbian': 'Српски'},
  'st': {'Sesotho': 'Sesotho'},
  'sn': {'Shona': 'ChiShona'},
  'sd': {'Sindhi': 'سنڌي'},
  'si': {'Sinhala': 'සිංහල'},
  'sk': {'Slovak': 'Slovenčina'},
  'sl': {'Slovenian': 'Slovenščina'},
  'so': {'Somali': 'Soomaali'},
  'es': {'Spanish': 'Español'},
  'su': {'Sundanese': 'Basa Sunda'},
  'sw': {'Swahili': 'Kiswahili'},
  'sv': {'Swedish': 'Svenska'},
  'tg': {'Tajik': 'Тоҷикӣ'},
  'ta': {'Tamil': 'தமிழ்'},
  'te': {'Telugu': 'తెలుగు'},
  'th': {'Thai': 'ไทย'},
  'tr': {'Turkish': 'Türkçe'},
  'uk': {'Ukrainian': 'Українська'},
  'ur': {'Urdu': 'اردو'},
  'ug': {'Uyghur': 'Uyƣurqə'},
  'uz': {'Uzbek': 'Oʻzbekcha'},
  'vi': {'Vietnamese': 'Tiếng Việt'},
  'cy': {'Welsh': 'Cymraeg'},
  'xh': {'Xhosa': 'isiXhosa'},
  'yi': {'Yiddish': 'ייִדיש'},
  'yo': {'Yoruba': 'Yorùbá'},
  'zu': {'Zulu': 'isiZulu'},
  'he': {'עברית': 'Hebrew'},
  'tt': {'Татар': 'Tatar'},
  'tk': {'Türkmen': 'Turkmen'},
};

const List<String> supportedLanguagesGoogle = [
  'af',
  'sq',
  'am',
  'ar',
  'hy',
  'az',
  'eu',
  'be',
  'bn',
  'bs',
  'bg',
  'ca',
  'ceb',
  'ny',
  'zh-CN',
  'zh-TW',
  'co',
  'hr',
  'cs',
  'da',
  'nl',
  'en',
  'eo',
  'et',
  'tl',
  'fi',
  'fr',
  'fy',
  'gl',
  'ka',
  'de',
  'el',
  'gu',
  'ht',
  'ha',
  'haw',
  'iw',
  'he',
  'hi',
  'hmn',
  'hu',
  'is',
  'ig',
  'id',
  'ga',
  'it',
  'ja',
  'jw',
  'kn',
  'kk',
  'km',
  'ko',
  'ku',
  'ky',
  'lo',
  'la',
  'lv',
  'lt',
  'lb',
  'mk',
  'mg',
  'ms',
  'ml',
  'mt',
  'mi',
  'mr',
  'mn',
  'my',
  'ne',
  'no',
  'ps',
  'fa',
  'pl',
  'pt',
  'pa',
  'ro',
  'ru',
  'sm',
  'gd',
  'sr',
  'st',
  'sn',
  'sd',
  'si',
  'sk',
  'sl',
  'so',
  'es',
  'su',
  'sw',
  'sv',
  'tg',
  'ta',
  'tt',
  'te',
  'th',
  'tr',
  'tk',
  'uk',
  'ur',
  'ug',
  'uz',
  'vi',
  'cy',
  'xh',
  'yi',
  'yo',
  'zu',
];

const List<String> supportedFlutter = [
  'af', 'am', 'ar', 'as', 'az', 'be', 'bg', 'bn', 'bs', 'ca', 'cs', 'cy', 'da',
  'de', 'el', 'en', 'es', 'et',
  'eu', 'fa', 'fi', 'fil', 'fr', 'gl', 'gsw', 'gu', 'he', 'hi', 'hr', 'hu',
  'hy', 'id', 'is', 'it', 'ja', 'ka',
  'kk', 'km', 'kn', 'ko', 'ky', 'lo', 'lt', 'lv', 'mk', 'ml', 'mn', 'mr', 'ms',
  'my', 'nb', 'ne', 'nl', 'no',
  'or', 'pa', 'pl', 'ps', 'pt', 'ro', 'ru', 'si', 'sk', 'sl', 'sq', 'sr', 'sv',
  'sw', 'ta', 'te', 'th', 'tl',
  'tr', 'uk', 'ur', 'uz', 'vi', 'zh', 'zu',
  // 'af', 'sq', 'am', 'ar', 'hy', 'az', 'eu', 'be', 'bn', 'bs', 'ca', 'cs', 'cy', 'da', 'de', 'el', 'en', 'eo',
  // 'et', 'tl', 'fi', 'fr', 'fy', 'gl', 'ka', 'de', 'el', 'gu', 'ht', 'ha', 'haw', 'iw', 'he', 'hi', 'hmn', 'hu',
  // 'is', 'ig', 'id', 'ga', 'it', 'ja', 'jw', 'kn', 'kk', 'km', 'ko', 'ku', 'ky', 'lo', 'la', 'lv', 'lt', 'lb',
  // 'mk', 'mg', 'ms', 'ml', 'mt', 'mi', 'mr', 'mn', 'my', 'ne', 'no', 'ps', 'fa', 'pl', 'pt', 'pa', 'ro', 'ru',
  // 'sm', 'gd', 'sr', 'st', 'sn', 'sd', 'si', 'sk', 'sl', 'so', 'es', 'su', 'sw', 'sv', 'tg', 'ta', 'tt', 'te',
  // 'th', 'tr', 'tk', 'uk', 'ur', 'ug', 'uz', 'vi', 'cy', 'xh', 'yi', 'yo', 'zu',
];
